@@ -72,7 +72,6 @@ use super::reverse_path;
 ///                    |&p| p == GOAL);
 /// assert_eq!(result.expect("no path found").1, 4);
 /// ```
-
 pub fn astar<N, C, FN, IN, FH, FS>(
     start: &N,
     neighbours: FN,
@@ -216,7 +215,7 @@ where
                         e.insert((p, new_cost));
                     }
                     Occupied(mut e) => if e.get().1 >= new_cost {
-                        let mut s = e.get_mut();
+                        let s = e.get_mut();
                         if s.1 > new_cost {
                             s.0.clear();
                             s.0.insert(node.clone());
@@ -316,6 +315,7 @@ impl<K: Ord, P> Ord for SmallestCostHolder<K, P> {
 }
 
 /// Iterator structure created by the `astar_bag` function.
+#[derive(Clone)]
 pub struct AstarSolution<N> {
     sinks: Vec<N>,
     parents: HashMap<N, Vec<N>>,
@@ -323,6 +323,8 @@ pub struct AstarSolution<N> {
     terminated: bool,
 }
 
+unsafe impl<N: Send> Send for AstarSolution<N> {}
+
 impl<N: Clone + Eq + Hash> AstarSolution<N> {
     fn complete(&mut self) {
         match self.current.last().cloned() {
@@ -356,11 +358,11 @@ impl<N: Clone + Eq + Hash> Iterator for AstarSolution<N> {
             return None;
         }
         self.complete();
-        let mut path = self.current
+        let path = self.current
             .iter()
+            .rev()
             .map(|v| v.last().cloned().unwrap())
             .collect::<Vec<_>>();
-        path.reverse();
         self.next_vec();
         self.terminated = self.current.is_empty();
         Some(path)
