@@ -2,7 +2,7 @@ use num_traits::Signed;
 use std::ops::{Index, IndexMut, Neg};
 
 /// Matrix of an arbitrary type
-#[derive(Debug)]
+#[derive(Clone, Debug)]
 pub struct Matrix<C> {
     /// Rows
     pub rows: usize,
@@ -11,6 +11,8 @@ pub struct Matrix<C> {
     data: Vec<C>,
 }
 
+unsafe impl<C: Send> Send for Matrix<C> {}
+
 impl<C: Clone> Matrix<C> {
     /// Create new matrix with an initial value.
     pub fn new(rows: usize, columns: usize, value: C) -> Matrix<C> {
@@ -35,16 +37,6 @@ impl<C: Clone> Matrix<C> {
     }
 }
 
-impl<C: Clone> Clone for Matrix<C> {
-    fn clone(&self) -> Matrix<C> {
-        Matrix {
-            rows: self.rows,
-            columns: self.columns,
-            data: self.data.clone(),
-        }
-    }
-}
-
 impl<C: Clone + Signed> Neg for Matrix<C> {
     type Output = Matrix<C>;
 
